/*!
 * planisphere
 *
 * A straightforward sitemap generator written in TypeScript.
 *
 * Copyright (c) 2020-present, cheap glitch
 *
 * Permission  to use,  copy, modify,  and/or distribute  this software  for any
 * purpose  with or  without  fee is  hereby granted,  provided  that the  above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
 * REGARD TO THIS  SOFTWARE INCLUDING ALL IMPLIED  WARRANTIES OF MERCHANTABILITY
 * AND FITNESS. IN NO EVENT SHALL THE  AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
 * INDIRECT, OR CONSEQUENTIAL  DAMAGES OR ANY DAMAGES  WHATSOEVER RESULTING FROM
 * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
 * OTHER  TORTIOUS ACTION,  ARISING OUT  OF  OR IN  CONNECTION WITH  THE USE  OR
 * PERFORMANCE OF THIS SOFTWARE.
 */
export declare type SitemapUrlLoc = string;
export declare type SitemapUrlLastmod = Date | number | string;
export declare type SitemapUrlChangefreq = 'always' | 'hourly' | 'daily' | 'weekly' | 'monthly' | 'yearly' | 'never';
export declare type SitemapUrlPriority = number | string;
interface GenerateOptions {
    defaults: Partial<SitemapUrl>;
    baseUrl: string;
    trailingSlash: boolean;
    pretty: boolean;
}
export interface SitemapUrl {
    loc: SitemapUrlLoc;
    lastmod?: SitemapUrlLastmod;
    changefreq?: SitemapUrlChangefreq;
    priority?: SitemapUrlPriority;
}
export declare function writeSitemaps(destination: string, urls: Array<string | SitemapUrl>, options?: Partial<GenerateOptions>): Promise<void>;
export declare function generateSitemapsIndex(sitemapFilenames: Array<string>, options?: Partial<GenerateOptions>, lastmod?: SitemapUrlLastmod): string | undefined;
export declare function generateSitemaps(urls: Array<string | SitemapUrl>, options?: Partial<GenerateOptions>): Array<string>;
export {};
